==> igniteui-react-layouts-18.2.0.tgz: package/esm5/lib/TooltipTextPresenter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, INotifyPropertyChanged_$type, PropertyChangedEventArgs, markType } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { DeviceUtils } from "igniteui-react-core";
import { BrushUtil } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
/**
 * @hidden
 */
var TooltipTextPresenter = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TooltipTextPresenter, _super);
    function TooltipTextPresenter(a) {
        var _this = _super.call(this) || this;
        _this.i = null;
        _this.f = null;
        _this.d = null;
        _this.g = DeviceUtils.g(42);
        _this.z = new Thickness(1, 20, 0, 20, 0);
        _this.v = BrushUtil.g(255, 237, 239, 245);
        _this.w = BrushUtil.g(255, 0, 0, 0);
        _this.j = "";
        _this.a = TooltipTextPresenter.c();
        _this.propertyChanged = null;
        _this.i = a;
        return _this;
    }
    Object.defineProperty(TooltipTextPresenter.prototype, "e", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "h", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            var b = this.g;
            this.g = a;
            if (this.g != b) {
                this.t("Height", b, this.g);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "aa", {
        get: function () {
            return this.z;
        },
        set: function (a) {
            var b = this.z;
            this.z = a;
            if (this.z != b) {
                this.t("Padding", b, this.z);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "x", {
        get: function () {
            return this.v;
        },
        set: function (a) {
            var b = this.v;
            this.v = a;
            if (this.v != b) {
                this.t("Background", b, this.v);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "y", {
        get: function () {
            return this.w;
        },
        set: function (a) {
            var b = this.w;
            this.w = a;
            if (this.w != b) {
                this.t("TextColor", b, this.w);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "o", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            var b = this.j;
            this.j = a;
            if (this.j != b) {
                this.t("Text", b, this.j);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "b", {
        get: function () {
            return this.a;
        },
        set: function (a) {
            var b = this.a;
            this.a = a;
            if (this.a != b) {
                this.t("FontInfo", b, this.a);
            }
        },
        enumerable: false,
        configurable: true
    });
    TooltipTextPresenter.prototype.s = function (a) {
        var _this = this;
        NativeUIComponent.at(this.i, [7, 3], function (b) {
            _this.e = b[0];
            _this.e.be = _this.aa;
            _this.e.x = _this.h;
            _this.e.a4 = _this.x;
            _this.e.am = _this;
            _this.f = b[1];
            _this.f.f = 1;
            _this.f.h = 1;
            _this.f.bh = false;
            _this.f.bi = _this.o;
            _this.f.a6 = _this.y;
            _this.f.bg = _this.b;
            _this.e.bj(_this.f);
            if (a != null) {
                a();
            }
        });
    };
    TooltipTextPresenter.c = function () {
        return ((function () {
            var $ret = new FontInfo();
            $ret.n = "Verdana";
            $ret.d = 14;
            $ret.q = "Normal";
            $ret.s = "Normal";
            $ret.o = "Normal";
            return $ret;
        })());
    };
    TooltipTextPresenter.prototype.r = function () {
        if (this.e != null) {
            this.e.be = this.aa;
            this.e.x = this.h;
            this.e.a4 = this.x;
        }
        if (this.f != null) {
            this.f.bi = this.o;
            this.f.a6 = this.y;
            this.f.bg = this.b;
        }
    };
    TooltipTextPresenter.prototype.t = function (a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.u(a, b, c);
    };
    TooltipTextPresenter.prototype.u = function (a, b, c) {
        switch (a) {
            case "Background":
            case "Padding":
            case "Height":
            case "FontInfo":
            case "Text":
            case "TextColor":
                this.r();
                break;
        }
    };
    TooltipTextPresenter.$t = markType(TooltipTextPresenter, 'TooltipTextPresenter', Base.$, [INotifyPropertyChanged_$type]);
    return TooltipTextPresenter;
}(Base));
export { TooltipTextPresenter };

==> igniteui-react-layouts-18.5.1.tgz: package/esm5/lib/TooltipTextPresenter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, INotifyPropertyChanged_$type, PropertyChangedEventArgs, markType } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { DeviceUtils } from "igniteui-react-core";
import { BrushUtil } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
import { Size } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var TooltipTextPresenter = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TooltipTextPresenter, _super);
    function TooltipTextPresenter(a) {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.f = null;
        _this.d = null;
        _this.h = DeviceUtils.g(42);
        _this.ab = new Thickness(1, 20, 0, 20, 0);
        _this.w = BrushUtil.h(255, 237, 239, 245);
        _this.x = BrushUtil.h(255, 0, 0, 0);
        _this.k = "";
        _this.a = TooltipTextPresenter.c();
        _this.g = NaN;
        _this.propertyChanged = null;
        _this.j = a;
        return _this;
    }
    Object.defineProperty(TooltipTextPresenter.prototype, "e", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "i", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            var b = this.h;
            this.h = a;
            if (this.h != b) {
                this.u("Height", b, this.h);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "ac", {
        get: function () {
            return this.ab;
        },
        set: function (a) {
            var b = this.ab;
            this.ab = a;
            if (this.ab != b) {
                this.u("Padding", b, this.ab);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "y", {
        get: function () {
            return this.w;
        },
        set: function (a) {
            var b = this.w;
            this.w = a;
            if (this.w != b) {
                this.u("Background", b, this.w);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "z", {
        get: function () {
            return this.x;
        },
        set: function (a) {
            var b = this.x;
            this.x = a;
            if (this.x != b) {
                this.u("TextColor", b, this.x);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "p", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            var b = this.k;
            this.k = a;
            if (this.k != b) {
                this.u("Text", b, this.k);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TooltipTextPresenter.prototype, "b", {
        get: function () {
            return this.a;
        },
        set: function (a) {
            var b = this.a;
            this.a = a;
            if (this.a != b) {
                this.u("FontInfo", b, this.a);
            }
        },
        enumerable: false,
        configurable: true
    });
    TooltipTextPresenter.prototype.t = function (a) {
        var _this = this;
        NativeUIComponent.at(this.j, [7, 3], function (b) {
            _this.e = b[0];
            _this.e.be = _this.ac;
            _this.e.x = _this.i;
            _this.e.a4 = _this.y;
            _this.e.am = _this;
            _this.f = b[1];
            _this.f.f = 1;
            _this.f.h = 1;
            _this.f.bh = false;
            _this.f.bi = _this.p;
            _this.f.a6 = _this.z;
            _this.f.bg = _this.b;
            _this.e.bj(_this.f);
            if (a != null) {
                a();
            }
        });
    };
    TooltipTextPresenter.prototype.aa = function () {
        if (isNaN_(this.g)) {
            var a = (document.createElement("canvas"));
            var b = a.getContext("2d");
            b.font = this.b.fontString;
            var c = b.measureText(this.p);
            this.g = c.width;
        }
        return new Size(1, this.ac.left + this.ac.right + this.g, this.ac.top + this.ac.bottom + this.i);
    };
    TooltipTextPresenter.c = function () {
        return ((function () {
            var $ret = new FontInfo();
            $ret.n = "Verdana";
            $ret.d = 14;
            $ret.q = "Normal";
            $ret.s = "Normal";
            $ret.o = "Normal";
            return $ret;
        })());
    };
    TooltipTextPresenter.prototype.s = function () {
        if (this.e != null) {
            this.e.be = this.ac;
            this.e.x = this.i;
            this.e.a4 = this.y;
        }
        if (this.f != null) {
            this.f.bi = this.p;
            this.f.a6 = this.z;
            this.f.bg = this.b;
        }
    };
    TooltipTextPresenter.prototype.u = function (a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.v(a, b, c);
    };
    TooltipTextPresenter.prototype.v = function (a, b, c) {
        switch (a) {
            case "Background":
            case "Padding":
            case "Height":
            case "FontInfo":
            case "TextColor":
                this.s();
                break;
            case "Text":
                this.g = NaN;
                this.s();
                break;
        }
    };
    TooltipTextPresenter.$t = markType(TooltipTextPresenter, 'TooltipTextPresenter', Base.$, [INotifyPropertyChanged_$type]);
    return TooltipTextPresenter;
}(Base));
export { TooltipTextPresenter };
